@@ -13,7 +13,7 @@ if TYPE_CHECKING:  # pragma: no cover
     from pipen import Proc
     from pipen.job import Job
 
-__version__ = "0.0.8"
+__version__ = "0.1.0"
 
 logger = get_logger("verbose", "info")
 
@@ -142,6 +142,10 @@ class PipenVerbose:
         failed_jobs = [
             job.index for job in proc.jobs if job.status == JobStatus.FAILED
         ]
+        if not failed_jobs:  # pragma: no cover
+            # could be triggered by Ctrl+C and all jobs are running
+            return
+
         job = proc.jobs[failed_jobs[0]]
 
         proc.log(
